# -*- coding: utf-8 -*-
#

__version__ = "4.4.0"
__author__ = u"Nico Schlömer"
__author_email__ = "nico.schloemer@gmail.com"
__copyright__ = u"Copyright (c) 2013-2019, {} <{}>".format(__author__, __author_email__)
__website__ = "https://github.com/nschloe/pygmsh"
__license__ = "License :: OSI Approved :: MIT License"
__status__ = "Development Status :: 5 - Production/Stable"
